@@ -105,8 +105,6 @@ class InterChange : private DataText
         static void *_sortResultsThread(void *arg);
         pthread_t  sortResultsThreadHandle;
         void muteQueueWrite(CommandBlock *getData);
-        std::string findHtmlManual(void);
-        std::string manualSearch(std::string dir2search, std::string path2match);
         void indirectTransfers(CommandBlock *getData, bool noForward = false);
         int indirectVector(CommandBlock *getData, SynthEngine *synth, unsigned char &newMsg, bool &guiTo, std::string &text);
         int indirectMidi(CommandBlock *getData, SynthEngine *synth, unsigned char &newMsg, bool &guiTo, std::string &text);
