@@ -2,7 +2,7 @@
     AlsaEngine.h
 
     Copyright 2009-2010, Alan Calvert
-    Copyright 2014-2018, Will Godfrey & others
+    Copyright 2014-2019, Will Godfrey & others
 
     This file is part of yoshimi, which is free software: you can
     redistribute it and/or modify it under the terms of the GNU General
@@ -17,7 +17,7 @@
     You should have received a copy of the GNU General Public License
     along with yoshimi.  If not, see <http://www.gnu.org/licenses/>.
 
-    Modified May 2018
+    Modified May 2019
 */
 
 #if defined(HAVE_ALSA)
@@ -26,19 +26,25 @@
 #define ALSA_ENGINE_H
 
 #include <pthread.h>
-#include <string>
 #include <alsa/asoundlib.h>
-
-using namespace std;
+#include <string>
 
 #include "MusicIO/MusicIO.h"
 
+#define MIDI_CLOCKS_PER_BEAT 24
+#define MIDI_CLOCK_DIVISION 3
+
+#define MIDI_SONGPOS_BEAT_DIVISION 4
+
+#define ALSA_MIDI_BPM_MEDIAN_WINDOW 48
+#define ALSA_MIDI_BPM_MEDIAN_AVERAGE_WINDOW 20
+
 class SynthEngine;
 
 class AlsaEngine : public MusicIO
 {
     public:
-        AlsaEngine(SynthEngine *_synth);
+        AlsaEngine(SynthEngine *_synth, BeatTracker *_beatTracker);
         ~AlsaEngine() { }
 
         bool openAudio(void);
@@ -49,8 +55,8 @@ class AlsaEngine : public MusicIO
         unsigned int getSamplerate(void) { return audio.samplerate; }
         int getBuffersize(void) { return audio.period_size; }
 
-        string audioClientName(void);
-        string midiClientName(void);
+        std::string audioClientName(void);
+        std::string midiClientName(void);
         int audioClientId(void) { return audio.alsaId; }
         int midiClientId(void) { return midi.alsaId; }
         virtual void registerAudioPort(int )  {}
@@ -68,20 +74,28 @@ class AlsaEngine : public MusicIO
         void Write(snd_pcm_uframes_t towrite);
         bool Recover(int err);
         bool xrunRecover(void);
-        bool alsaBad(int op_result, string err_msg);
+        bool alsaBad(int op_result, std::string err_msg);
         void closeAudio(void);
         void closeMidi(void);
 
+        std::string findMidiClients(snd_seq_t *seq);
+
         void *AudioThread(void);
         static void *_AudioThread(void *arg);
         void *MidiThread(void);
         static void *_MidiThread(void *arg);
 
+        void handleMidiEvents(uint64_t clock);
+        void handleMidiClockSilence(uint64_t clock);
+
         snd_pcm_sframes_t (*pcmWrite)(snd_pcm_t *handle, const void *data,
                                       snd_pcm_uframes_t nframes);
 
+        void handleSongPos(float beat);
+        void handleMidiClock(uint64_t clock);
+
         struct {
-            string             device;
+            std::string        device;
             snd_pcm_t         *handle;
             unsigned int       period_count;
             unsigned int       samplerate;
@@ -93,11 +107,28 @@ class AlsaEngine : public MusicIO
         } audio;
 
         struct {
-            string              device;
-            snd_seq_t           *handle;
-            snd_seq_addr_t      addr;
-            int                 alsaId;
-            pthread_t           pThread;
+            std::string        device;
+            snd_seq_t         *handle;
+            snd_seq_addr_t     addr;
+            int                alsaId;
+            pthread_t          pThread;
+
+            // When receiving MIDI clock messages, to avoid precision errors
+            // (MIDI_CLOCKS_PER_BEAT (24) does not cleanly divide 1), store
+            // every third (MIDI_CLOCK_DIVISION) beat here. This is reset only
+            // every third clock ticks or on song repositioning. Note that the
+            // value is not necessarily an exact multiple of
+            // 1/MIDI_CLOCK_DIVISION, but we only ever add
+            // (1/MIDI_CLOCK_DIVISION) beats to it.
+            float             lastDivSongBeat;
+            float             lastDivMonotonicBeat;
+            // Reset to zero every MIDI_CLOCK_DIVISION. This is actually an
+            // integer, but stored as float for calculation purposes.
+            float             clockCount;
+
+            float             prevBpms[ALSA_MIDI_BPM_MEDIAN_WINDOW];
+            int               prevBpmsPos;
+            int64_t           prevClockUs;
         } midi;
 };
 
