@@ -7,6 +7,7 @@
     Copyright 2017-2019 Will Godfrey
     Copyright 2020 Kristian Amlie & others
     Copyright 2022 Ichthyostega
+    Copyright 2023 Will Godfrey and others
 
     This file is part of yoshimi, which is free software: you can redistribute
     it and/or modify it under the terms of the GNU General Public
@@ -95,7 +96,7 @@ namespace{ // Implementation helpers...
 
 
 PADnoteParameters::PADnoteParameters(uchar pID, uchar kID, SynthEngine *_synth)
-    : Presets(_synth)
+    : ParamBase(_synth)
     , Pmode{0}
     , Pquality{}
     , PProfile{}
@@ -168,7 +169,6 @@ PADnoteParameters::PADnoteParameters(uchar pID, uchar kID, SynthEngine *_synth)
     , sampleTime{0}
     , wavetablePhasePrng{}
 {
-    setpresettype("Ppadsyth");
     FreqEnvelope->ASRinit(64, 50, 64, 60);
     AmpEnvelope->ADSRinit_dB(0, 40, 127, 25);
     FilterEnvelope->ADSRinit_filter(64, 40, 64, 70, 60, 64);
@@ -335,7 +335,9 @@ vector<float> PADnoteParameters::buildProfile(size_t size)
         {
             x = 0.0f;
             makezero = true;
-        } else {
+        }
+        else
+        {
             if (x >1.0f)
             {
                 x = 1.0f;
@@ -806,7 +808,7 @@ void PADnoteParameters::activate_wavetable()
     {                          // Note: don't pick up new waveTable while fading
         PADStatus::mark(PADStatus::CLEAN, synth->interchange, partID,kitID);
         futureBuild.swap(waveTable);
-        presetsUpdated();
+        paramsChanged();
         sampleTime = 0;
     }
     else
@@ -850,7 +852,7 @@ void PADnoteParameters::mute_and_rebuild_synchronous()
     {
         using std::swap;
         swap(waveTable, *result);
-        presetsUpdated();
+        paramsChanged();
         sampleTime = 0;
     }
 }
