@@ -29,7 +29,7 @@
 #ifndef PAD_NOTE_PARAMETERS_H
 #define PAD_NOTE_PARAMETERS_H
 
-#include "Params/Presets.h"
+#include "Params/ParamCheck.h"
 #include "Misc/RandomGen.h"
 #include "Misc/BuildScheduler.h"
 #include "Params/RandomWalk.h"
@@ -158,7 +158,7 @@ private:
 
 
 
-class PADnoteParameters : public Presets
+class PADnoteParameters : public ParamBase
 {
         static constexpr size_t SIZE_HARMONIC_PROFILE = 512;
         static constexpr size_t PROFILE_OVERSAMPLING = 16;
