@@ -5,10 +5,11 @@
     Copyright (C) 2002-2005 Nasca Octavian Paul
     Copyright 2009, Alan Calvert
     Copyright 2017-2019, Will Godfrey
-    Copyright 2020 Kristian Amlie
+    Copyright 2020-2022 Kristian Amlie & others
+    Copyright 2023 Will Godfrey and others
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of the GNU Library General Public
+    it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
@@ -25,11 +26,16 @@
 
 */
 
+#include "Misc/SynthEngine.h"
 #include "Params/SUBnoteParameters.h"
+#include "Misc/NumericFuncs.h"
 
-SUBnoteParameters::SUBnoteParameters(SynthEngine *_synth) : Presets(_synth)
+using func::setAllPan;
+using func::power;
+
+
+SUBnoteParameters::SUBnoteParameters(SynthEngine *_synth) : ParamBase(_synth)
 {
-    setpresettype("Psubsyth");
     AmpEnvelope = new EnvelopeParams(64, 1, synth);
     AmpEnvelope->ADSRinit_dB(0, 40, 127, 25);
     FreqEnvelope = new EnvelopeParams(64, 0, synth);
@@ -47,7 +53,9 @@ SUBnoteParameters::SUBnoteParameters(SynthEngine *_synth) : Presets(_synth)
 void SUBnoteParameters::defaults(void)
 {
     PVolume = 96;
-    setPan(PPanning = 64);
+    setPan(PPanning = 64, synth->getRuntime().panLaw);
+    PRandom = false;
+    PWidth = 63;
     PAmpVelocityScaleFunction = 90;
     Pfixedfreq = 0;
     PfixedfreqET = 0;
@@ -74,7 +82,6 @@ void SUBnoteParameters::defaults(void)
 
     for (int n = 0; n < MAX_SUB_HARMONICS; ++n)
     {
-        PfilterChanged[n] = 0;
         Phmag[n] = 0;
         Phrelbw[n] = 64;
     }
@@ -102,15 +109,11 @@ SUBnoteParameters::~SUBnoteParameters()
 }
 
 
-void SUBnoteParameters::setPan(char pan)
+void SUBnoteParameters::setPan(char pan, unsigned char panLaw)
 {
     PPanning = pan;
-    if (!randomPan())
-    {
-        float t = (float)(PPanning - 1) / 126.0f;
-        pangainL = cosf(t * HALFPI);
-        pangainR = cosf((1.0f - t) * HALFPI);
-    }
+    if (!PRandom)
+        setAllPan(PPanning, pangainL, pangainR, panLaw);
     else
         pangainL = pangainR = 0.7f;
 }
@@ -118,6 +121,8 @@ void SUBnoteParameters::setPan(char pan)
 
 void SUBnoteParameters::add2XML(XMLwrapper *xml)
 {
+    // currently not used
+    // bool yoshiFormat = synth->usingYoshiType;
     xml->information.SUBsynth_used = 1;
 
     xml->addpar("num_stages",Pnumstages);
@@ -138,7 +143,17 @@ void SUBnoteParameters::add2XML(XMLwrapper *xml)
     xml->beginbranch("AMPLITUDE_PARAMETERS");
         xml->addparbool("stereo", (Pstereo) ? 1 : 0);
         xml->addpar("volume",PVolume);
-        xml->addpar("panning",PPanning);
+        // new yoshi type
+        xml->addpar("pan_pos", PPanning);
+        xml->addparbool("random_pan", PRandom);
+        xml->addpar("random_width", PWidth);
+
+        // legacy
+        if (PRandom)
+            xml->addpar("panning", 0);
+        else
+            xml->addpar("panning",PPanning);
+
         xml->addpar("velocity_sensing",PAmpVelocityScaleFunction);
         xml->beginbranch("AMPLITUDE_ENVELOPE");
             AmpEnvelope->add2XML(xml);
@@ -201,15 +216,14 @@ void SUBnoteParameters::add2XML(XMLwrapper *xml)
 void SUBnoteParameters::updateFrequencyMultipliers(void)
 {
     float par1 = POvertoneSpread.par1 / 255.0f;
-    float par1pow = powf(10.0f,
-            -(1.0f - POvertoneSpread.par1 / 255.0f) * 3.0f);
+    float par1pow = power<10>(-(1.0f - POvertoneSpread.par1 / 255.0f) * 3.0f);
     float par2 = POvertoneSpread.par2 / 255.0f;
     float par3 = 1.0f - POvertoneSpread.par3 / 255.0f;
     float result;
     float tmp = 0.0f;
     int   thresh = 0;
 
-    for(int n = 0; n < MAX_SUB_HARMONICS; ++n)
+    for (int n = 0; n < MAX_SUB_HARMONICS; ++n)
     {
         float n1     = n + 1.0f;
         switch(POvertoneSpread.type)
@@ -290,7 +304,24 @@ void SUBnoteParameters::getfromXML(XMLwrapper *xml)
         int xpar = xml->getparbool("stereo", (Pstereo) ? 1 : 0);
         Pstereo = (xpar != 0) ? true : false;
         PVolume=xml->getpar127("volume",PVolume);
-        setPan(xml->getpar127("panning",PPanning));
+        int test = xml->getpar127("random_width", UNUSED);
+        if (test < 64) // new Yoshi type
+        {
+            PWidth = test;
+            setPan(xml->getpar127("pan_pos",PPanning), synth->getRuntime().panLaw);
+            PRandom = xml->getparbool("random_pan", PRandom);
+        }
+        else // legacy
+        {
+            setPan(xml->getpar127("panning",PPanning), synth->getRuntime().panLaw);
+            if (PPanning == 0)
+            {
+                PPanning = 64;
+                PRandom = true;
+                PWidth = 63;
+            }
+        }
+
         PAmpVelocityScaleFunction=xml->getpar127("velocity_sensing",PAmpVelocityScaleFunction);
         if (xml->enterbranch("AMPLITUDE_ENVELOPE"))
         {
@@ -363,7 +394,7 @@ void SUBnoteParameters::getfromXML(XMLwrapper *xml)
 
 float SUBnoteParameters::getLimits(CommandBlock *getData)
 {
-    float value = getData->data.value.F;
+    float value = getData->data.value;
     int request = int(getData->data.type & TOPLEVEL::type::Default);
     int control = getData->data.control;
     int insert = getData->data.insert;
@@ -378,7 +409,7 @@ float SUBnoteParameters::getLimits(CommandBlock *getData)
     unsigned char learnable = TOPLEVEL::type::Learnable;
     type |= learnable;
 
-    if (insert == TOPLEVEL::insert::harmonicAmplitude || insert == TOPLEVEL::insert::harmonicPhaseBandwidth)
+    if (insert == TOPLEVEL::insert::harmonicAmplitude || insert == TOPLEVEL::insert::harmonicBandwidth)
     { // do harmonics stuff
         if (control >= MAX_SUB_HARMONICS)
         {
@@ -386,7 +417,7 @@ float SUBnoteParameters::getLimits(CommandBlock *getData)
             return 1;
         }
 
-        if (insert == TOPLEVEL::insert::harmonicPhaseBandwidth)
+        if (insert == TOPLEVEL::insert::harmonicBandwidth)
             def = 64;
         else if (control == 0)
             def = 127;
@@ -396,9 +427,9 @@ float SUBnoteParameters::getLimits(CommandBlock *getData)
         switch (request)
         {
             case TOPLEVEL::type::Adjust:
-                if(value < 0)
+                if (value < 0)
                     value = 0;
-                else if(value > 127)
+                else if (value > 127)
                     value = 127;
                 break;
             case TOPLEVEL::type::Minimum:
@@ -425,10 +456,15 @@ float SUBnoteParameters::getLimits(CommandBlock *getData)
             def = 64;
             break;
 
-        case SUBSYNTH::control::enable:
+        case SUBSYNTH::control::enableRandomPan:
             max = 1;
             break;
 
+        case SUBSYNTH::control::randomWidth:
+            def = 63;
+            max = 63;
+            break;
+
         case SUBSYNTH::control::bandwidth:
             def = 40;
             break;
@@ -538,9 +574,9 @@ float SUBnoteParameters::getLimits(CommandBlock *getData)
     switch (request)
     {
         case TOPLEVEL::type::Adjust:
-            if(value < min)
+            if (value < min)
                 value = min;
-            else if(value > max)
+            else if (value > max)
                 value = max;
         break;
         case TOPLEVEL::type::Minimum:
