@@ -69,7 +69,7 @@ OscilGen::OscilGen(fft::Calc& fft_, Resonance *res_, SynthEngine *_synth, OscilP
 void OscilGen::changeParams(OscilParameters *params_)
 {
     params = params_;
-    oscilupdate.changePresets(*params);
+    oscilupdate.changeParams(*params);
 }
 
 void OscilGen::defaults(void)
