@@ -35,9 +35,8 @@
 using func::power;
 
 
-Resonance::Resonance(SynthEngine *_synth) : Presets(_synth)
+Resonance::Resonance(SynthEngine *_synth) : ParamBase(_synth)
 {
-    setpresettype("Presonance");
     defaults();
 }
 
