@@ -6,7 +6,7 @@
     Copyright 2009-2010, Alan Calvert
     Copyright 2016 Will Godfrey
     Copyright 2017 Jesper Lloyd
-    Copyright 2018 Will Godfrey and others
+    Copyright 2018-2024 Will Godfrey and others
 
     Idea originally derived from work by Greg Ercolano
     (http://seriss.com/people/erco/fltk/)
@@ -99,7 +99,9 @@ void DynTooltip::dynshow(float timeout)
         reposition();
         update();
         Fl_Menu_Window::show();
-    } else {
+    }
+    else
+    {
         Fl::add_timeout(timeout, delayedShow, this);
     }
 }
