@@ -127,7 +127,7 @@ enum ValueType {
 
 float collect_readData(SynthEngine *synth, float value, unsigned char control, unsigned char part, unsigned char kititem = UNUSED, unsigned char engine = UNUSED, unsigned char insert = UNUSED, unsigned char parameter = UNUSED, unsigned char offset = UNUSED, unsigned char miscmsg = UNUSED, unsigned char request = UNUSED);
 
-void collect_data(SynthEngine *synth, float value, unsigned char action, unsigned char type, unsigned char control, unsigned char part, unsigned char kititem = UNUSED, unsigned char engine = UNUSED, unsigned char insert = UNUSED, unsigned char parameter = UNUSED, unsigned char offset = UNUSED, unsigned char miscmsg = UNUSED);
+void collect_writeData(SynthEngine *synth, float value, unsigned char action, unsigned char type, unsigned char control, unsigned char part, unsigned char kititem = UNUSED, unsigned char engine = UNUSED, unsigned char insert = UNUSED, unsigned char parameter = UNUSED, unsigned char offset = UNUSED, unsigned char miscmsg = UNUSED);
 
 void alert(SynthEngine *synth, string message);
 int choice(SynthEngine *synth, string one, string two, string three, string message);
@@ -245,8 +245,16 @@ inline void setVisible(SynthEngine *synth, bool v, std::string filename)
 
 inline void checkSane(int& x, int& y, int& w, int& h, int defW, int defH, bool halfsize = false)
 {
-    int maxW = Fl::w() - 5; // wiggle room
-    int maxH = Fl::h() - 30; // space for minimal titlebar
+    int minX, minY, maxW, maxH;
+    Fl::screen_xywh(minX, minY, maxW, maxH, x, y, w, h);
+
+    // Pretend that this is the center screen, which makes calculations easier.
+    // We will reverse this at the bottom.
+    x -= minX;
+    y -= minY;
+
+    maxW -= 5; // wiggle room
+    maxH -= 30; // space for minimal titlebar
 
     if ((w / defW) != (h / defH)) // ratio
         w = h / defH * defW; // doesn't matter which one we pick!
@@ -289,7 +297,40 @@ inline void checkSane(int& x, int& y, int& w, int& h, int defW, int defH, bool h
         if (y < 30)
             y = 30;
     }
+
+    // Restore position relative to screen position.
+    x += minX;
+    y += minY;
+
     //std::cout << "x " << x << "  y " << y << "  w " << w << "  h " << h << std::endl;
 }
 
+inline void voiceOscUpdate(SynthEngine *synth_, int npart, int kititem, int nvoice, int &nvs, int &nvp)
+{
+        SynthEngine *synth = synth_;
+        int extOsc= collect_readData(synth,0,ADDVOICE::control::voiceOscillatorSource, npart, kititem, PART::engine::addVoice1 + nvoice);
+        if (collect_readData(synth,0,ADDVOICE::control::externalOscillator, npart, kititem, PART::engine::addVoice1 + nvoice) >= 0)
+        {
+            while (collect_readData(synth,0,ADDVOICE::control::externalOscillator, npart, kititem, PART::engine::addVoice1 + nvs) >= 0)
+                nvp = nvs = collect_readData(synth,0,ADDVOICE::control::externalOscillator, npart, kititem, PART::engine::addVoice1 + nvs);
+        }
+        else if (extOsc >= 0)
+            nvs = extOsc;
+
+        return;
+
+        // the original code
+
+        /*if (pars->VoicePar[nvoice].PVoice  >= 0)
+        {
+            while (pars->VoicePar[nvs].PVoice  >= 0)
+                nvp = nvs = pars->VoicePar[nvs].PVoice;
+        }
+        else if (pars->VoicePar[nvoice].Pextoscil  >= 0)
+            nvs = pars->VoicePar[nvoice].Pextoscil;
+        oscil->changeParams(pars->VoicePar[nvs].POscil);
+        osc->init(oscil,0,pars->VoicePar[nvp].Poscilphase, synth);
+        */
+}
+
 #endif
