@@ -2,6 +2,7 @@
     globals.h - general static definitions
 
     Copyright 2018-2023, Will Godfrey & others
+    Copyright 2024 Kristian Amlie
 
     This file is part of yoshimi, which is free software: you can redistribute
     it and/or modify it under the terms of the GNU General Public
@@ -161,6 +162,7 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
         insertEffects,
         bank = 244, // F4
         config = 248, // F8
+        guideLocation = 249,
         message = 250, // FA
         windowTitle = 252,
         /* The above is read-only and uses 'value' as the location of the
@@ -187,6 +189,11 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
             Write = 64,
             Integer = 128 // false = float
         };
+
+        // copy/paste preset types
+        const int List = Adjust; // fetch all entries of this group, alternatively group type
+        const int Copy = LearnRequest; // from section to file
+        const int Paste = Learnable; // from file to section, alternatively delete entry
     }
 
     namespace action {
@@ -199,7 +206,7 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
             // space for any other sources
             noAction = 15, // internal use (also a mask for the above)
             // remaining used bit-wise
-            forceUpdate = 32,
+            forceUpdate = 32, // currently only used by the GUI
             loop = 64, // internal use
             lowPrio = 128,
             muteAndLoop = 192
@@ -365,7 +372,7 @@ namespace BANK // usage BANK::control::
         selectBank = 16, // in root, by ID or read ID + name
         renameBank, // or read just the name
         createBank,
-        deleteBank, // not yet - currently 'remove' at top level
+        deleteBank, // not yet (currently done in main)
         findBankSize,
         selectFirstBankToSwap,
         selectSecondBankAndSwap,
@@ -471,14 +478,14 @@ namespace MIDI // usage MIDI::control::noteOn
         resetAllControllers,
         allNotesOff = 123,
 
-        pitchWheelInner = 128,
-        channelPressureInner,
-        keyPressureInner,
+        pitchWheelAdjusted = 128,
+        channelPressureAdjusted,
+        keyPressureAdjusted,
         soloType,
         soloCC,
 
         // the following are generated internally for MIDI-learn and
-        // are deliberately well outside the range on normal MIDI
+        // are deliberately well outside the range of normal MIDI
         pitchWheel = 640, // seen as 128
         channelPressure,  // 129
         keyPressure,      // 130
@@ -537,7 +544,7 @@ namespace SCALES // usage SCALES::control::refFrequency
         badChars,
         valueTooBig,
         valueTooSmall,
-        emptyEntry
+        emptyEntry // 0
     };
 }
 
@@ -744,6 +751,7 @@ namespace ADDSYNTH // usage ADDSYNTH::control::volume
         detuneType, // L35 cents, L10 cents, E100 cents, E1200 cents
         coarseDetune,
         relativeBandwidth = 39,
+        bandwidthMultiplier,
 
         stereo = 112,
         randomGroup,
@@ -785,13 +793,14 @@ namespace ADDVOICE // usage ADDVOICE::control::volume
         enableFrequencyLFO,
 
         unisonFrequencySpread = 48,
+        unisonSpreadCents,
         unisonPhaseRandomise,
         unisonStereoSpread,
         unisonVibratoDepth,
         unisonVibratoSpeed,
         unisonSize,
         unisonPhaseInvert, // None, Random, 50%, 33%, 25%, 20%
-        enableUnison = 56,
+        enableUnison,
 
         bypassGlobalFilter = 64, // TODO not seen on return?
         enableFilter = 68,
@@ -1080,6 +1089,7 @@ namespace EFFECT // usage EFFECT::control::level
         level = 0, // volume, wet/dry, gain for EQ
         panning, // band for EQ
         frequency, // time reverb, delay echo, L/R-mix dist, Not EQ
+        sepLRDelay = 7, // Echo
         preset = 16, // not EQ
         bpm,
         bpmStart,
@@ -1097,7 +1107,7 @@ namespace EFFECT // usage EFFECT::control::level
     };
 
     enum type : unsigned char { // sits above part kits
-        none = NUM_KIT_ITEMS,
+        none = NUM_KIT_ITEMS, // must not be moved
         reverb,
         echo,
         chorus,
