@@ -192,7 +192,7 @@ static void *mainThread(void *arg)
             boxLb.box(FL_EMBOSSED_FRAME);
             boxLb.labelsize(16);
             boxLb.labelfont(FL_BOLD);
-            boxLb.labelcolor(YOSHI_COLOUR);
+            boxLb.labelcolor(0x0000e100);
         }
         winSplash.border(false);
         if (splashSet && bShowGui)
@@ -422,7 +422,7 @@ int main(int argc, char *argv[])
     std::string Config = file::loadText(Home + "/.config/yoshimi/yoshimi.config");
     if (Config.empty())
     {
-        std::cout << "Not there" << std::endl;
+        std::cout << "Config not there" << std::endl;
 #ifdef GUI_FLTK
         showSplash = true;
 #endif
